@@ -4,6 +4,14 @@ from magicapi import g
 
 from fastapi.responses import JSONResponse
 
+from pydantic import BaseModel
+
+
+class MagicExceptionModel(BaseModel):
+    status_code: int = 452
+    message: str
+    json_response: dict = {}
+
 
 class MagicException(Exception):
     def __init__(self, message: str, json_response: dict = None):
@@ -11,6 +19,9 @@ class MagicException(Exception):
         self.message: str = message
         self.json_response: dict = json_response or {}
 
+    def make_model(self) -> MagicExceptionModel:
+        return MagicExceptionModel(**self.__dict__)
+
 
 class BackendException(MagicException):
     pass
@@ -30,11 +41,9 @@ class TwilioException(MagicException):
 
 @g.app.exception_handler(MagicException)
 def backend_exception_handler(request: Request, exc: MagicException):
+    print("EXC", exc.__dict__)
+    magic_exception_model = exc.make_model()
     return JSONResponse(
-        status_code=exc.status_code,
-        content={
-            "success": False,
-            "message": f"{exc.message}",
-            "json_response": exc.json_response,
-        },
+        status_code=magic_exception_model.status_code,
+        content=magic_exception_model.dict(),
     )
