@@ -1,6 +1,7 @@
 from functools import wraps
 
-from magicapi import settings
+# from magicapi import settings
+from magicapi import g
 from magicapi.Errors import BackendException
 
 from magicapi.Services.Doorman import CurrentUser
@@ -14,7 +15,7 @@ def segment(keywords=None):
     def inner_function(f):
         @wraps(f)
         async def wrapper(*args, **kwargs):
-            if not settings.segment_write_key:
+            if not g.settings.segment_write_key:
                 raise BackendException(
                     message="You cannot use the segment decorator without the SEGMENT_WRITE_KEY env variable."
                 )
