@@ -32,7 +32,10 @@ class MagicSettings(BaseSettings):
     app_name: str = "GOAT Server"
     version: str = "0.0.1"
 
-    service: str = 'default_service'
+    service: str = "default_service"
+
+    # for span sls
+    use_span: bool = True
 
     # for dev
     print_level = 1
@@ -88,6 +91,7 @@ class MagicSettings(BaseSettings):
     class Config:
         env_file = find_file(glob_string="*.env") or ".env"
 
+
 # If you want to make the env variables from .env available
 # from dotenv import load_dotenv
 # if os.path.exists(env_path):
